<?php

/**
 * It extends Zend_Pdf class and it implements a new method to embed javascript
 * code into a PDF document.
 * 
 * @author   Andrea Venturi <a.venturi@gmail.com>
 * @license  http://framework.zend.com/license/new-bsd     New BSD License
 */
class My_Pdf extends Zend_Pdf
{
	/**
	 * Set the javascript code that will be embedded into the PDF document
	 * Thanks to:
	 * http://osdir.com/ml/php.zend.framework.formats/2007-03/msg00010.html
	 * http://framework.zend.com/issues/browse/ZF-3155
	 * 
	 * @param  string $javascript 
	 * @return void
	 */
	public function setEmbeddedJS($javascript = null)
	{
		// Names container
		if ( null === $javascript || '' === $javascript) {
			throw new Zend_Pdf_Exception('Javascript must be set.');
		}
		
		$this->setJavaScript($javascript);
		$js_code = array(
			'S'  => new Zend_Pdf_Element_Name('JavaScript'),
			'JS' => new Zend_Pdf_Element_String($this->getJavascript())
		);
		$embed[] = new Zend_Pdf_Element_String('EmbeddedJS');
		$embed[] = $this->_objFactory->newObject(new Zend_Pdf_Element_Dictionary($js_code));
		$js_ref  = $this->_objFactory->newObject(new Zend_Pdf_Element_Dictionary(array('Names' => new Zend_Pdf_Element_Array($embed))));
		
		$this->_trailer->Root->Names = new Zend_Pdf_Element_Dictionary(array('JavaScript' => $js_ref));
	}
}